@@ -76,9 +76,9 @@ def __get_keyring_secret(name: str):
     return keyring.get_password(service_name, username) or '???'
 
 
-OmegaConf.register_resolver('azkv', __get_secret)
-OmegaConf.register_resolver('kube', __get_kubernetes_secret)
-OmegaConf.register_resolver('keyring', __get_keyring_secret)
+OmegaConf.register_new_resolver('azkv', __get_secret)
+OmegaConf.register_new_resolver('kube', __get_kubernetes_secret)
+OmegaConf.register_new_resolver('keyring', __get_keyring_secret)
 
 
 CURRENT_CONFIG = None
